@@ -26,16 +26,15 @@ class Deployer(object):
         environment="prod",
         local=False,
         subdomain=None,
-        domain="alexwiss.com",
-        pool_id="us-east-1_RIZE20fug",
-        certificate_id="6ed4866c-16dd-4db8-81cf-fb1316227679",
+        domain=None,
+        pool_id=None,
+        certificate_id=None,
     ):
         self.dir = dir
         script_dir = os.path.dirname(os.path.realpath(__file__))
         self.jinja = Environment(loader=FileSystemLoader(script_dir))
         self.project_name = name
         self.environment = environment
-        os.environ["ENVIRONMENT"] = environment
         self.docker = docker
         self.local = local
         self.subdomain = subdomain
@@ -44,6 +43,7 @@ class Deployer(object):
         self.certificate_id = certificate_id
         client = boto3.client("sts")
         self.account_id = client.get_caller_identity()["Account"]
+        os.environ["ENVIRONMENT"] = environment
 
         # Appending the current path to grab any other files.
         os.sys.path.append(os.path.abspath(self.dir))
@@ -202,7 +202,7 @@ class Deployer(object):
         subprocess.run(pip_cmd, cwd=self.dir)
 
         # Copy template in there.
-        shutil.copyfile("bld.yml", f"{build_path}/template.yml")
+        shutil.copyfile("bld.yml", f"{build_path}/template.yaml")
 
         # Copying Python code to build directory.
         # TODO: Add symlinks for all Python files so live updated works.
@@ -280,7 +280,7 @@ class Deployer(object):
             "--s3-bucket",
             f"{self.project_name}-bld-{self.environment}",
             "--template-file",
-            ".aws-sam/build/template.yml",
+            ".aws-sam/build/template.yaml",
             "--parameter-overrides",
             f"ENVIRONMENT={self.environment}",
             "--no-fail-on-empty-changeset",
@@ -297,6 +297,7 @@ class Deployer(object):
 
     def start_api(self, method="local"):
         """Run the API layer locally."""
+        os.environ["ENVIRONMENT"] = "local"
         if method == "sam":
             self._start_api_sam()
 
@@ -327,7 +328,9 @@ class Deployer(object):
         # Deploy queues to localstack.
         for queue in queues:
             print(f"Deploying queue {queue['name']}.")
-            _ = sqs.create_queue(QueueName=f"legoon-{queue['name']}-prod")
+            _ = sqs.create_queue(
+                QueueName=f"{self.project_name}-{queue['name']}-{self.environment}"
+            )
 
         try:
             _ = iam.create_role(
@@ -490,6 +493,12 @@ class Deployer(object):
         self._build()
         subprocess.run(["sam", "local", "invoke", function], cwd=self.dir, check=True)
 
+    def start(self):
+        """
+        Runs any functions and queues locally using native Python.
+        """
+        self._source_files()
+
 
 if __name__ == "__main__":
     deployer = Deployer("pilotproj", "../pilotproj")
